slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPRefineScheme

The scheme used for solving linear systems during iterative refinement

### Synopsis

    typedef enum { PEP_REFINE_SCHEME_SCHUR=1,
                   PEP_REFINE_SCHEME_MBE,
                   PEP_REFINE_SCHEME_EXPLICIT } PEPRefineScheme;

### See Also

PEPSetRefine()

### Level

intermediate

### Location

include/slepcpep.h
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages